==> jc-1.4.0.tar.gz: javax/swing/ToolTipManager__24stillInsideTimerAction.h <==
// public class javax.swing.ToolTipManager$stillInsideTimerAction

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 371e371e970c0fc4 javax_swing_ToolTipManager__24stillInsideTimerAction

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_ToolTipManager__24stillInsideTimerAction_H_
#define _JC_javax_swing_ToolTipManager__24stillInsideTimerAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_ToolTipManager$object;

// Typedefs
typedef struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$sub_refs	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$sub_refs;
typedef struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$sub_nonrefs	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$sub_nonrefs;
typedef struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$refs	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$refs;
typedef struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$nonrefs	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$nonrefs;
typedef struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$object	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$object;

typedef const struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vmethods	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vmethods;
typedef const struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vtable	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vtable;
typedef const struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vtype	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vtype;

// Constructors
extern void _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$method$_init$4f7171db22e499d9(_jc_env *, struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$object *, struct _jc_javax_swing_ToolTipManager$object *);

// Virtual methods
extern void _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vmethods	javax_swing_ToolTipManager__24stillInsideTimerAction;
};

// Vtype
struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vtype {
	_jc_type			type;
	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$sub_refs {
	struct _jc_javax_swing_ToolTipManager$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$refs {
    _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$sub_refs	javax_swing_ToolTipManager__24stillInsideTimerAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$sub_nonrefs	javax_swing_ToolTipManager__24stillInsideTimerAction;
};

// Object instance structure
struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$object {
	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vtype	*vtype;
	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vtype _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_ToolTipManager__24stillInsideTimerAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$class_object;

#endif	/* _JC_javax_swing_ToolTipManager__24stillInsideTimerAction_H_ */

==> jc-1.4.6.tar.gz: javax/swing/ToolTipManager__24stillInsideTimerAction.h <==
// public class javax.swing.ToolTipManager$stillInsideTimerAction

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4437b8eff4346384 javax_swing_ToolTipManager__24stillInsideTimerAction

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_ToolTipManager__24stillInsideTimerAction_H_
#define _JC_javax_swing_ToolTipManager__24stillInsideTimerAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_ToolTipManager$object;

// Typedefs
typedef struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$sub_refs	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$sub_refs;
typedef struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$sub_nonrefs	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$sub_nonrefs;
typedef struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$refs	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$refs;
typedef struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$nonrefs	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$nonrefs;
typedef struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$object	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$object;

typedef const struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vmethods	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vmethods;
typedef const struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vtable	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vtable;
typedef const struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vtype	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vtype;

// Constructors
extern void _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$method$_init$4f7171db22e499d9(_jc_env *, struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$object *, struct _jc_javax_swing_ToolTipManager$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vmethods	javax_swing_ToolTipManager__24stillInsideTimerAction;
};

// Vtype
struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vtype {
	_jc_type			type;
	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$sub_refs {
	struct _jc_javax_swing_ToolTipManager$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$refs {
    _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$sub_refs	javax_swing_ToolTipManager__24stillInsideTimerAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$sub_nonrefs	javax_swing_ToolTipManager__24stillInsideTimerAction;
};

// Object instance structure
struct _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$object {
	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vtype	*vtype;
	_jc_javax_swing_ToolTipManager__24stillInsideTimerAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$vtype _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_ToolTipManager__24stillInsideTimerAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_ToolTipManager__24stillInsideTimerAction$class_object;

#endif	/* _JC_javax_swing_ToolTipManager__24stillInsideTimerAction_H_ */
